0.3.11 (2020-08-25)
-------------------

Update :

* Support django 3.1


0.3.10 (2019-12-13)
-------------------

Update:

* Update documentation
* Support django 3.0


0.3.9 (2019-10-22)
-------------------

New:

* Extract from terra-back helper for X-Accel-Redirect, to serve medias

0.3.8  (2019-10-15)
-------------------

Update :

* Delete TokenGenerator since it was splitted to single package django-token-tools

0.3.7  (2019-10-11)
-------------------

Update :

* Add a TokenGenerator to allow authentication through URL

0.3.5  (2019-09-24)
-------------------

Fixes :

* fix settings call

0.3.1  (2019-09-24)
-------------------

Update :

* add default settings for HOSTNAME and FRONT_URL

0.3.0  (2019-09-23)
-------------------

First release from splitted terracommon.core
